"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllMainnetLpTokens = exports.getMainnetOrcaLpTokens = exports.getMainnetRaydiumLpTokens = exports.getMainnetTokens = void 0;
const raydium_sdk_1 = require("@raydium-io/raydium-sdk");
const sdk_1 = require("@orca-so/sdk");
const types_1 = require("./types");
function getMainnetTokens() {
    var tokens = [];
    for (const [, splInfo] of Object.entries(raydium_sdk_1.MAINNET_SPL_TOKENS)) {
        const tokenInfo = {
            value: splInfo.symbol,
            label: splInfo.symbol,
            logo: `https://sdk.raydium.io/icons/${splInfo.mint}.png`,
            mint: splInfo.mint,
            decimals: splInfo.decimals
        };
        tokens.push(tokenInfo);
    }
    return tokens;
}
exports.getMainnetTokens = getMainnetTokens;
function getMainnetRaydiumLpTokens() {
    var lpTokens = [];
    for (const [, lpInfo] of Object.entries(raydium_sdk_1.MAINNET_LP_TOKENS)) {
        const lpTokenInfo = {
            value: lpInfo.symbol,
            label: lpInfo.symbol,
            baseLogoUrl: `https://sdk.raydium.io/icons/${lpInfo.base.mint}.png`,
            quoteLogoUrl: `https://sdk.raydium.io/icons/${lpInfo.quote.mint}.png`,
            baseMint: lpInfo.base.mint,
            quoteMint: lpInfo.quote.mint,
            lpTokenMint: lpInfo.mint,
            decimals: lpInfo.decimals,
            venue: types_1.LiquidityPoolVenues.RAYDIUM
        };
        lpTokens.push(lpTokenInfo);
    }
    return lpTokens;
}
exports.getMainnetRaydiumLpTokens = getMainnetRaydiumLpTokens;
function getMainnetOrcaLpTokens(connection) {
    var lpTokens = [];
    const lpMints = Object.keys(sdk_1.OrcaPoolConfig);
    const orca = (0, sdk_1.getOrca)(connection);
    for (const mint of lpMints) {
        var orcaPool = orca.getPool(sdk_1.OrcaPoolConfig[mint]);
        var baseToken = orcaPool.getTokenA();
        var quoteToken = orcaPool.getTokenB();
        var lpToken = orcaPool.getPoolTokenMint();
        const lpTokenInfo = {
            value: `${baseToken.tag.toUpperCase()}-${quoteToken.tag.toUpperCase()}`,
            label: `${baseToken.tag.toUpperCase()}-${quoteToken.tag.toUpperCase()}`,
            baseLogoUrl: `https://sdk.raydium.io/icons/${baseToken.mint.toBase58()}.png`,
            quoteLogoUrl: `https://sdk.raydium.io/icons/${quoteToken.mint.toBase58()}.png`,
            baseMint: baseToken.mint.toBase58(),
            quoteMint: quoteToken.mint.toBase58(),
            lpTokenMint: lpToken.toBase58(),
            decimals: 6,
            venue: types_1.LiquidityPoolVenues.ORCA
        };
        lpTokens.push(lpTokenInfo);
    }
    return lpTokens;
}
exports.getMainnetOrcaLpTokens = getMainnetOrcaLpTokens;
function getAllMainnetLpTokens(connection) {
    return getMainnetRaydiumLpTokens().concat(getMainnetOrcaLpTokens(connection));
}
exports.getAllMainnetLpTokens = getAllMainnetLpTokens;
